@@ -7,11 +7,11 @@ Elive -  Elluminate Live (c) client library
 
 =head1 VERSION
 
-Version 0.22
+Version 0.23
 
 =cut
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 use base qw{Class::Data::Inheritable};
 
@@ -44,9 +44,6 @@ Elive is a set of Perl modules for the integration and automation of
 Elluminate Live sites. In particular, it aids in the management of users
 and meetings.
 
-It provides convenient Perl object bindings to entities. These are accessed
-and updated via the Elluminate Live SOAP/XML command interface.
-
 =head1 BACKGROUND
 
 Elluminate Live (c) is is a web tool for virtual online classrooms.
@@ -55,10 +52,15 @@ It is suitable for online collaboration, demonstrations, meetings, web
 conferences, seminars and IT deployment, training and support.
 
 Users, Meetings and other resources are stored in a management database.
-These can managed via the Elluminate Live web interface.
+These can managed via the Elluminate Live SOAP API.
 
-Most actions that can be performed via the web interface are also
-available from Elluminate Live's SOAP/XML command interface.
+Most actions that can be performed via the web interface can also be
+achieved via the SOAP API. This is known as the I<Command Toolkit> and
+is detailed in chapter 4 of the I<Elluminate Live! Software Developers
+Kit>.
+
+This module provides Perl object to entity bindings to Elluminate Live
+databases via the command toolkit..
 
 =cut
 
@@ -239,7 +241,7 @@ checkMeetingPreload createGroup createMeeting createPreload createRecording
 createUser deleteGroup deleteMeeting deleteMeetingPreload deleteParticipant deleteRecording
 deletePreload deleteUser getGroup getMeeting getMeetingParameters getPreload
 getPreloadStream getRecording getRecordingStream getServerDetails getServerParameters getUser
-importPreload importRecording listGroups listMeetingPreloads listMeetings listParticipants
+importPreload importRecording isParticipant listGroups listMeetingPreloads listMeetings listParticipants
 listPreloads listRecordings listUserMeetingsByDate listUsers resetGroup
 resetParticipantList setParticipantList streamPreload streamRecording
 updateMeeting updateMeetingParameters updateRecording updateServerParameters
